@@ -153,6 +153,8 @@ def variants(
                 gene_obj=gene_obj,
                 build=case_obj["genome_build"],
             )
+            # Update case variants count
+            adapter.case_variants_count(case_obj["_id"], case_obj["owner"], force_update_case=True)
 
         except Exception as e:
             LOG.warning(e)
