@@ -41,6 +41,41 @@ def get_correct_date(date_info):
     return datetime.datetime.now()
 
 
+def parse_custom_images(config_data):
+    """Parse information on custom images assigned to the case."""
+    VALID_IMAGE_SUFFIXES = ["gif", "svg", "png", "jpg", "jpeg"]
+    LOG.debug("Parse custom images")
+
+    # sort custom image sections
+    parsed_sections = {}
+    for section_name, images in config_data.get("custom_images", {}).items():
+        parsed_images = []
+        for image in images:
+            # skip entries that are not recognized as image on suffix
+            path = Path(image["path"])
+            if not path.suffix[1:] in VALID_IMAGE_SUFFIXES:
+                LOG.warning(f"Image: {path.name} is not recognized as an image, skipping")
+                continue
+            # load image file to memory
+            with open(image["path"], "rb") as image_file:
+                parsed_images.append(
+                    {
+                        "title": image["title"],
+                        "description": image["description"],
+                        "data": bytes(image_file.read()),
+                        "width": image.get("width"),
+                        "height": image.get("height"),
+                        "format": "svg+xml" if path.suffix[1:] == "svg" else path.suffix[1:],
+                    }
+                )
+        # store parsed section
+        if len(parsed_images) > 0:
+            parsed_sections[section_name] = parsed_images
+        else:
+            LOG.warning(f"Section: {section_name} had no valid images, skipping")
+    return parsed_sections
+
+
 def parse_case_data(
     config=None,
     ped=None,
@@ -113,6 +148,9 @@ def parse_case_data(
             panel.strip() for panel in config_data["default_gene_panels"]
         ]
 
+    # handle scout/commands/load/case.py
+    config_data["custom_images"] = parse_custom_images(config_data)
+
     ##################### Add information from peddy if existing #####################
     config_data["peddy_ped"] = peddy_ped or config_data.get("peddy_ped")
     config_data["peddy_sex_check"] = peddy_sex or config_data.get("peddy_sex")
@@ -316,28 +354,27 @@ def parse_individual(sample):
             'analysis_type': str,
             'vcf2cytosure': str,
             'capture_kits': list(str),
-
             'upd_sites_bed': str,
             'upd_regions_bed': str,
             'rhocall_bed': str,
             'rhocall_wig': str,
             'tiddit_coverage_wig': str,
-
             'predicted_ancestry' = str,
-
             'is_sma': boolean,
             'is_sma_carrier': boolean,
             'smn1_cn' = int,
             'smn2_cn' = int,
             'smn2delta78_cn' = int,
             'smn_27134_cn' = int,
-
             'tumor_type': str,
             'tmb': str,
             'msi': str,
             'tumor_purity': float,
             'tissue_type': str,
             'chromograph_images': str
+            'vcf2cytosure': str
+            'rna_coverage_bigwig': str
+            'splice_junctions_bed': str
         }
 
     """
@@ -408,6 +445,10 @@ def parse_individual(sample):
     # Path to downloadable vcf2cytosure file
     ind_info["vcf2cytosure"] = sample.get("vcf2cytosure")
 
+    # Path to splice junctions data
+    ind_info["rna_coverage_bigwig"] = sample.get("rna_coverage_bigwig")
+    ind_info["splice_junctions_bed"] = sample.get("splice_junctions_bed")
+
     # load sma file if it is not done at this point!
     ind_info["is_sma"] = sample.get("is_sma", None)
     ind_info["is_sma_carrier"] = sample.get("is_sma_carrier", None)
@@ -536,6 +577,7 @@ def parse_case(config):
         "gene_fusion_report_research": config.get("gene_fusion_report_research"),
         "multiqc": config.get("multiqc"),
         "track": config.get("track", "rare"),
+        "custom_images": config.get("custom_images", {}),
     }
 
     # add SMN info
