@@ -4,6 +4,7 @@ import itertools
 import json
 import logging
 import os
+from base64 import b64encode
 
 import query_phenomizer
 import requests
@@ -12,11 +13,10 @@ from bson.objectid import ObjectId
 from flask import current_app, flash, redirect, request, url_for
 from flask_login import current_user
 from flask_mail import Message
+from requests.auth import HTTPBasicAuth
 from xlsxwriter import Workbook
 
 from scout.constants import (
-    ACMG_MAP,
-    ACMG_OPTIONS,
     CANCER_PHENOTYPE_MAP,
     MT_COV_STATS_HEADER,
     MT_EXPORT_HEADER,
@@ -35,7 +35,8 @@ from scout.constants.variant_tags import (
 from scout.export.variant import export_mt_variants
 from scout.parse.matchmaker import genomic_features, hpo_terms, omim_terms, parse_matches
 from scout.server.blueprints.variant.controllers import variant as variant_decorator
-from scout.server.extensions import matchmaker, store
+from scout.server.blueprints.variants.controllers import get_manual_assessments
+from scout.server.extensions import RerunnerError, matchmaker, rerunner, store
 from scout.server.utils import institute_and_case
 from scout.utils.scout_requests import post_request_json
 
@@ -89,11 +90,15 @@ def case(store, institute_obj, case_obj):
     suspects = [
         store.variant(variant_id) or variant_id for variant_id in case_obj.get("suspects", [])
     ]
-    _populate_acmg(suspects)
+    _populate_assessments(suspects)
     causatives = [
         store.variant(variant_id) or variant_id for variant_id in case_obj.get("causatives", [])
     ]
-    _populate_acmg(causatives)
+    _populate_assessments(causatives)
+
+    # get evaluated variants
+    evaluated_variants = store.evaluated_variants(case_obj["_id"])
+    _populate_assessments(evaluated_variants)
 
     # check for partial causatives and associated phenotypes
     partial_causatives = []
@@ -105,6 +110,7 @@ def case(store, institute_obj, case_obj):
                 "hpo_terms": values.get("phenotype_terms"),
             }
             partial_causatives.append(causative_obj)
+    _populate_assessments(partial_causatives)
 
     # Set of all unique genes in the default gene panels
     distinct_genes = set()
@@ -202,10 +208,11 @@ def case(store, institute_obj, case_obj):
     # complete OMIM diagnoses specific for this case
     omim_terms = {term["disease_nr"]: term for term in store.case_omim_diagnoses(case_obj)}
 
-    # get evaluated variants
-    evaluated_variants = store.evaluated_variants(case_obj["_id"])
-
-    _populate_acmg(evaluated_variants)
+    if case_obj.get("custom_images"):
+        # re-encode images as base64
+        for img_section in case_obj["custom_images"].values():
+            for img in img_section:
+                img["data"] = b64encode(img["data"]).decode("utf-8")
 
     data = {
         "status_class": STATUS_MAP.get(case_obj["status"]),
@@ -230,26 +237,22 @@ def case(store, institute_obj, case_obj):
     return data
 
 
-def _populate_acmg(evaluated_variants):
+def _populate_assessments(variants_list):
     """
-    Add ACMG classification options for display of ACMG badges to variants.
+    Add ACMG classification, manual_rank, cancer_tier, dismiss_variant and mosaic_tags assessment options to a variant object.
     The list of variant objects can contain plain variant_id strings for deleted / no longer loaded variants.
     These should not be populated.
 
     Args:
-        evaluated_variants: list(variant_obj or str)
+        variants_list: list(variant_obj or str)
 
     Returns:
 
     """
-
-    for variant in evaluated_variants:
-
-        if not isinstance(variant, str) and isinstance(variant.get("acmg_classification"), int):
-            classification = ACMG_MAP.get(variant["acmg_classification"])
-            for option in ACMG_OPTIONS:
-                if option["code"] == classification:
-                    variant["acmg_classification"] = option
+    for variant in variants_list:
+        if isinstance(variant, str):
+            continue
+        variant["clinical_assessments"] = get_manual_assessments(variant)
 
 
 def _check_outdated_gene_panel(panel_obj, latest_panel):
@@ -279,19 +282,19 @@ def _check_outdated_gene_panel(panel_obj, latest_panel):
     return extra_genes, missing_genes
 
 
-def case_report_content(store, institute_obj, case_obj):
+def case_report_content(store, institute_id, case_name):
     """Gather contents to be visualized in a case report
 
     Args:
         store(adapter.MongoAdapter)
-        institute_obj(models.Institute)
-        case_obj(models.Case)
+        institute_id(str): _id of an institute
+        case_name(str): case display name
 
     Returns:
         data(dict)
 
     """
-    variant_types = {
+    VARIANT_TYPES = {
         "causatives_detailed": "causatives",
         "partial_causatives_detailed": "partial_causatives",
         "suspects_detailed": "suspects",
@@ -301,9 +304,10 @@ def case_report_content(store, institute_obj, case_obj):
         "dismissed_detailed": "dismiss_variant",
         "commented_detailed": "is_commented",
     }
-    data = case_obj
 
-    for individual in data["individuals"]:
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    data = {"case": case_obj, "institute": institute_obj}
+    for individual in data["case"].get("individuals", []):
         try:
             sex = int(individual.get("sex", 0))
         except ValueError as err:
@@ -335,7 +339,7 @@ def case_report_content(store, institute_obj, case_obj):
     data["genetic_models"] = dict(GENETIC_MODELS)
     data["report_created_at"] = datetime.datetime.now().strftime("%Y-%m-%d %H:%M")
 
-    evaluated_variants = {vt: [] for vt in variant_types}
+    evaluated_variants = {vt: [] for vt in VARIANT_TYPES}
     # We collect all causatives (including the partial ones) and suspected variants
     # These are handeled in separate since they are on case level
     for var_type in ["causatives", "suspects", "partial_causatives"]:
@@ -354,8 +358,8 @@ def case_report_content(store, institute_obj, case_obj):
     ## get variants for this case that are either classified, commented, tagged or dismissed.
     for var_obj in store.evaluated_variants(case_id=case_obj["_id"]):
         # Check which category it belongs to
-        for vt in variant_types:
-            keyword = variant_types[vt]
+        for vt in VARIANT_TYPES:
+            keyword = VARIANT_TYPES[vt]
             # When found we add it to the categpry
             # Eac variant can belong to multiple categories
             if keyword not in var_obj:
@@ -794,6 +798,40 @@ def rerun(store, mail, current_user, institute_id, case_name, sender, recipient)
         LOG.error("Cannot send rerun message: no recipient defined in config.")
 
 
+def call_rerunner(store, institute_id, case_name, metadata):
+    """Call rerunner with updated pedigree metadata."""
+    # define the data to be passed
+    payload = {"case_id": case_name, "sample_ids": [m["sample_id"] for m in metadata]}
+
+    cnf = rerunner.connection_settings
+    url = cnf.get("entrypoint")
+    if not url:
+        raise ValueError("Rerunner API entrypoint not configured")
+    auth = HTTPBasicAuth(current_user.email, cnf.get("api_key"))
+    LOG.info(f"Sending request -- {url}; params={payload}")
+    resp = requests.post(
+        url,
+        params=payload,
+        json=metadata,
+        timeout=rerunner.timeout,
+        headers={"Content-Type": "application/json"},
+        auth=auth,
+    )
+
+    if resp.status_code == 200:
+        LOG.info(f"Reanalysis was successfully started; case: {case_name}")
+        # get institute, case and user objects for adding a notification of the rerun to the database
+        institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+        user_obj = store.user(current_user.email)
+        link = url_for("cases.case", institute_id=institute_id, case_name=case_name)
+        store.request_rerun(institute_obj, case_obj, user_obj, link)
+        # notfiy the user of the rerun
+        flash(f"Reanalysis was successfully started; case: {case_name}", "info")
+
+    else:
+        raise RerunnerError(f"{resp.reason}, {resp.status_code}")
+
+
 def update_default_panels(store, current_user, institute_id, case_name, panel_ids):
     """Update default panels for a case."""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -1218,12 +1256,12 @@ def matchmaker_matches(request, institute_id, case_name):
     return data
 
 
-def matchmaker_match(request, match_type, institute_id, case_name):
+def matchmaker_match(request, target, institute_id, case_name):
     """Initiate a MatchMaker match against either other Scout patients or external nodes
 
     Args:
         request(werkzeug.local.LocalProxy)
-        match_type(str): 'internal' or 'external'
+        target(str): 'internal' for matches against internal patients, or id of a specific node
         institute_id(str): _id of an institute
         case_name(str): display name of a case
     """
@@ -1235,7 +1273,7 @@ def matchmaker_match(request, match_type, institute_id, case_name):
     ok_responses = 0
     for patient in query_patients:
         json_resp = None
-        if match_type == "internal":  # Interal match against other patients on the MME server
+        if target == "internal":  # Interal match against other patients on the MME server
             json_resp = matchmaker.match_internal(patient)
             if json_resp.get("status_code") != 200:
                 flash(
@@ -1250,6 +1288,8 @@ def matchmaker_match(request, match_type, institute_id, case_name):
             # Against every node
             nodes = [node["id"] for node in matchmaker.connected_nodes]
             for node in nodes:
+                if node != target:
+                    continue
                 json_resp = matchmaker.match_external(patient_id, node)
                 if json_resp.get("status_code") != 200:
                     flash(
@@ -1259,6 +1299,9 @@ def matchmaker_match(request, match_type, institute_id, case_name):
                     continue
                 ok_responses += 1
     if ok_responses > 0:
-        flash("Matching request sent. Look for eventual matches in 'Matches' page.", "info")
+        flash(
+            "Matching request sent. Click on 'Past Matches' to review eventual matching results.'",
+            "info",
+        )
 
     return ok_responses
