@@ -188,6 +188,11 @@ def variant(
 
     managed_variant = store.find_managed_variant_id(variant_obj["variant_id"])
 
+    if variant_obj.get("category") == "cancer":
+        variant_obj["matching_tiered"] = store.matching_tiered(
+            variant_obj, user_institutes(store, current_user)
+        )
+
     # Gather display information for the genes
     variant_obj.update(predictions(variant_obj.get("genes", [])))
 
@@ -211,7 +216,7 @@ def variant(
     variant_obj["end_position"] = end_position(variant_obj)
 
     # Add general variant links
-    variant_obj.update(get_variant_links(variant_obj, int(genome_build)))
+    variant_obj.update(get_variant_links(institute_obj, variant_obj, int(genome_build)))
     variant_obj["frequencies"] = frequencies(variant_obj)
     if variant_category in ["snv", "cancer"]:
         # This is to convert a summary of frequencies to a string
