@@ -25,12 +25,13 @@ from scout.constants import (
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
     SO_TERMS,
+    VARIANT_FILTERS,
 )
 from scout.constants.variants_export import EXPORT_HEADER, VERIFIED_VARIANTS_HEADER
 from scout.export.variant import export_verified_variants
 from scout.server.blueprints.variant.utils import clinsig_human, predictions
 from scout.server.links import cosmic_link, str_source_link
-from scout.server.utils import case_append_alignments, institute_and_case
+from scout.server.utils import case_append_alignments, institute_and_case, user_institutes
 
 from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm, VariantFiltersForm
 
@@ -267,12 +268,11 @@ def get_manual_assessments(variant_obj):
                 assessment["label"] = "Dismissed"
                 assessment["title"] = "dismiss:<br>"
                 for reason in variant_obj[assessment_type]:
-                    if not isinstance(reason, int):
-                        reason = int(reason)
-                        assessment["title"] += "<strong>{}</strong> - {}<br><br>".format(
-                            dismiss_variant_options[reason]["label"],
-                            dismiss_variant_options[reason]["description"],
-                        )
+                    reason = int(reason)
+                    assessment["title"] += "<strong>{}</strong> - {}<br><br>".format(
+                        dismiss_variant_options[reason]["label"],
+                        dismiss_variant_options[reason]["description"],
+                    )
                 assessment["display_class"] = "secondary"
 
             if assessment_type == "mosaic_tags":
@@ -385,6 +385,10 @@ def parse_variant(
         institute_obj, case=case_obj, variant_id=variant_obj["variant_id"], comments=True
     )
 
+    variant_obj["matching_tiered"] = store.matching_tiered(
+        variant_obj, user_institutes(store, current_user)
+    )
+
     if variant_genes:
         variant_obj.update(predictions(variant_genes))
         if variant_obj.get("category") == "cancer":
@@ -425,9 +429,81 @@ def parse_variant(
     else:
         variant_obj["first_rep_gene"] = None
 
+    # annotate filters
+    variant_obj["filters"] = [
+        VARIANT_FILTERS[f]
+        for f in map(lambda x: x.lower(), variant_obj["filters"])
+        if f in VARIANT_FILTERS
+    ]
+
     return variant_obj
 
 
+def download_str_variants(case_obj, variant_objs):
+    """Download filtered STR variants for a case to an excel file
+
+    Args:
+        case_obj(dict)
+        variant_objs(PyMongo cursor)
+
+    Returns:
+        an HTTP response containing a csv file
+    """
+
+    def generate(header, lines):
+        yield header + "\n"
+        for line in lines:
+            yield line + "\n"
+
+    DOCUMENT_HEADER = [
+        "Index",
+        "Repeat locus",
+        "Repeat unit",
+        "Estimated size",
+        "Reference size",
+        "Status",
+        "Genotype",
+        "Chromosome",
+        "Position",
+    ]
+
+    export_lines = []
+    for variant in variant_objs:
+        variant_line = []
+        variant_line.append(str(variant.get("variant_rank", "")))  # index
+        variant_line.append(variant.get("str_repid"))  # Repeat locus
+        variant_line.append(
+            variant.get("str_display_ru", variant.get("str_ru", ""))
+        )  # Reference repeat unit
+        variant_line.append(
+            variant.get("alternative", "").replace("STR", "").replace("<", "").replace(">", "")
+        )  # Estimated size
+        variant_line.append(str(variant.get("str_ref", "")))  # Reference size
+        variant_line.append(str(variant.get("str_status", "")))  # Status
+        gt_cell = ""
+        for sample in variant["samples"]:
+            if sample["genotype_call"] == "./.":
+                continue
+            gt_cell += f"{sample['display_name']}:{sample['genotype_call']} "
+
+        variant_line.append(gt_cell)  # Genotype
+        variant_line.append(variant["chromosome"])  # Chromosome
+        variant_line.append(str(variant["position"]))  # Position
+
+        export_lines.append(",".join(variant_line))
+
+    headers = Headers()
+    headers.add(
+        "Content-Disposition",
+        "attachment",
+        filename=str(case_obj["display_name"]) + "-filtered-str_variants.csv",
+    )
+    # return a csv with the exported variants
+    return Response(
+        generate(",".join(DOCUMENT_HEADER), export_lines), mimetype="text/csv", headers=headers
+    )
+
+
 def download_variants(store, case_obj, variant_objs):
     """Download filtered variants for a case to an excel file
 
@@ -672,6 +748,7 @@ def cancer_variants(store, institute_id, case_name, variants_query, variant_coun
                 if len(in_panels & set(form.gene_panels.data)) > 0:
                     secondary_gene = gene
         variant_obj["second_rep_gene"] = secondary_gene
+        variant_obj["clinical_assessments"] = get_manual_assessments(variant_obj)
         variants_list.append(variant_obj)
 
     data = dict(
@@ -1007,27 +1084,32 @@ def check_form_gene_symbols(
 
     errors = {
         "non_clinical_symbols": {
-            "alert": "Gene not included in case clinical list",
+            "message": "Genes not included in gene panel versions in use when loading this case (clinical list)",
             "gene_list": non_clinical_symbols,
+            "label": "info",
         },
         "not_found_symbols": {
-            "alert": "HGNC symbol not present in genes collection",
+            "message": "HGNC symbols not present in database's genes collection",
             "gene_list": not_found_symbols,
+            "label": "warning",
         },
         "not_found_ids": {
-            "alert": "HGNC id not present in genes collection",
+            "message": "HGNC ids not present in database's genes collection",
             "gene_list": not_found_ids,
+            "label": "warning",
         },
         "outdated_symbols": {
-            "alert": "Clinical list contains a panel with an outdated symbol for genes",
+            "message": "Gene panel versions used for loading variants of this case (clinical list) contain outdated gene symbols. The current HGNC id was found on the clinical list.",
             "gene_list": outdated_symbols,
+            "label": "info",
         },
     }
 
     # warn user if gene symbols are corresponding to any current gene,
-    for error, item in errors.items():
-        if item["gene_list"]:
-            flash(f"{item['alert']}: {item['gene_list']}", "warning")
+    for error in errors.values():
+        if not error["gene_list"]:
+            continue
+        flash(f'{error["message"]}:{error["gene_list"]}', error["label"])
 
     return updated_hgnc_symbols
 
@@ -1192,7 +1274,6 @@ def dismiss_variant_list(store, institute_obj, case_obj, link_page, variants_lis
         dismiss_reasons(list): list of dismiss options.
     """
     user_obj = store.user(current_user.email)
-    dismiss_reasons = [int(reason) for reason in dismiss_reasons]
     for variant_id in variants_list:
         variant_obj = store.variant(variant_id)
         if variant_obj is None:
