@@ -16,10 +16,19 @@ MAIL_PORT = 587
 MAIL_USE_TLS = True
 MAIL_USE_SSL = False
 
+# Filename of accrediation bagde image in server/bluprints/public/static
+# If null no badge is displayed in scout
+ACCREDITATION_BADGE = "swedac-1926-iso17025.png"
+
 # Configure gens service
 # GENS_HOST = "127.0.0.1"
 # GENS_PORT = 5000
 
+# Connection details for communicating with a rerunner service
+# RERUNNER_API_ENTRYPOINT = "http://rerunner:5001/v1.0/rerun"
+# RERUNNER_TIMEOUT = 10
+# RERUNNER_API_KEY = "I am the Keymaster of Gozer"
+
 # MatchMaker connection parameters
 # - Tested with PatientMatcher (https://github.com/Clinical-Genomics/patientMatcher) -
 # MME_ACCEPTS = "application/vnd.ga4gh.matchmaker.v1.0+json"
@@ -58,6 +67,8 @@ ACCEPT_LANGUAGES = ["en", "sv"]
 
 # FEATURE FLAGS
 SHOW_CAUSATIVES = True
+SHOW_OBSERVED_VARIANT_ARCHIVE = True
+HIDE_ALAMUT_LINK = False
 
 # OMIM API KEY: Required for downloading definitions from OMIM (https://www.omim.org/api)
 # OMIM_API_KEY = 'valid_omim_api_key'
