@@ -13,8 +13,10 @@ from scout.utils.ensembl_rest_clients import EnsemblBiomartClient
 
 LOG = logging.getLogger(__name__)
 
-HPO_URL = "http://purl.obolibrary.org/obo/hp/hpoa/{}"
-HPOTERMS_URL = "http://purl.obolibrary.org/obo/hp.obo"
+HPO_URL = "https://ci.monarchinitiative.org/view/hpo/job/hpo.annotations/lastSuccessfulBuild/artifact/rare-diseases/util/annotation/{}"
+HPOTERMS_URL = (
+    "https://raw.githubusercontent.com/obophenotype/human-phenotype-ontology/master/hp.obo"
+)
 TIMEOUT = 20
 
 
@@ -167,7 +169,7 @@ def fetch_hpo_terms():
     Returns:
         res(list(str)): A list with the lines
     """
-    url = "http://purl.obolibrary.org/obo/hp.obo"
+    url = HPOTERMS_URL
 
     return fetch_resource(url)
 
