@@ -4,19 +4,22 @@ import pathlib
 import tempfile
 
 from scout.commands.download.hpo import hpo as hpo_cmd
+from scout.utils.scout_requests import fetch_hpo_files
 
 
 def test_download_hpo_cmd(mocker, empty_mock_app):
     """Test download hpo command"""
+
     # GIVEN a temporary directory
     mock_app = empty_mock_app
     runner = mock_app.test_cli_runner()
 
-    mocker.patch("scout.commands.download.hpo.print_hpo")
+    mocker.patch("scout.utils.scout_requests.fetch_resource")
     with tempfile.TemporaryDirectory() as dir_name:
         the_dir = pathlib.Path(dir_name)
         # WHEN running the command
         result = runner.invoke(hpo_cmd, ["-o", the_dir])
+
         # THEN check it exits without problems
         assert result.exit_code == 0
         assert "Download HPO" in result.output
