@@ -56,7 +56,7 @@ from scout.load.hpo import load_hpo
 from scout.load.transcript import load_transcripts
 from scout.log import init_log
 from scout.models.hgnc_map import HgncGene
-from scout.parse.case import parse_case
+from scout.parse.case import parse_case, parse_custom_images
 from scout.parse.ensembl import parse_ensembl_exons, parse_ensembl_transcripts, parse_transcripts
 from scout.parse.exac import parse_exac_genes
 from scout.parse.hgnc import parse_hgnc_genes
@@ -201,6 +201,34 @@ def ensembl_genes(request, gene_bulk):
     return _ensembl_genes
 
 
+@pytest.fixture
+def ensembl_liftover_response():
+    """Returns a  response from ensembl liftover api"""
+    _response = {
+        "mappings": [
+            {
+                "mapped": {
+                    "assembly": "GRCh38",
+                    "seq_region_name": "X",
+                    "end": 1039365,
+                    "start": 1039265,
+                    "coord_system": "chromosome",
+                    "strand": 1,
+                },
+                "original": {
+                    "strand": 1,
+                    "coord_system": "chromosome",
+                    "start": 1000000,
+                    "seq_region_name": "X",
+                    "end": 1000100,
+                    "assembly": "GRCh37",
+                },
+            }
+        ]
+    }
+    return _response
+
+
 @pytest.fixture(scope="function")
 def gene_bulk(genes):
     """Return a list with HgncGene objects"""
@@ -280,7 +308,7 @@ def phenotype_to_genes_file(request):
 
 @pytest.fixture
 def hpo_terms_handle(request, hpo_terms_file):
-    """Get a file handle to a hpo terms file (http://purl.obolibrary.org/obo/hp.obo)"""
+    """Get a file handle to a hpo terms file (https://raw.githubusercontent.com/obophenotype/human-phenotype-ontology/master/hp.obo)"""
     hpo_lines = get_file_handle(hpo_terms_file)
     return hpo_lines
 
@@ -389,6 +417,8 @@ def cancer_case_obj(request, cancer_parsed_case):
     case["individuals"][0]["sex"] = "1"
     case["individuals"][1]["sex"] = "1"
 
+    case["phenotype_terms"] = []  # do not assign any phenotype
+
     return case
 
 
@@ -798,6 +828,8 @@ def real_populated_database(request, real_panel_database, parsed_case):
 
     LOG.info("Adding case to real adapter")
     case_obj = build_case(parsed_case, adapter)
+    # adapt custom images
+    case_obj["custom_images"] = parse_custom_images(case_obj)
     adapter._add_case(case_obj)
 
     return adapter
